==> SWMM5-5.1.15.tar.gz: SWMM5-5.1.15/swmm5/swmm5/keywords.h <==
//-----------------------------------------------------------------------------
//   keywords.h
//
//   Project: EPA SWMM5
//   Version: 5.1
//   Date:    03/19/14   (Build 5.1.000)
//            03/19/15   (Build 5.1.008)
//            05/10/18   (Build 5.1.013)
//   Author:  L. Rossman
//
//   Exportable keyword dictionary
//
//   Build 5.1.008:
//   - Keyword arrays listed in alphabetical order.
//
//   Build 5.1.013:
//   - New keyword array defined for surcharge method.
//-----------------------------------------------------------------------------

#ifndef KEYWORDS_H
#define KEYWORDS_H


extern char* BuildupTypeWords[];
extern char* CurveTypeWords[];
extern char* DividerTypeWords[];
extern char* DynWaveMethodWords[];
extern char* EvapTypeWords[];
extern char* FileModeWords[];
extern char* FileTypeWords[];
extern char* FlowUnitWords[];
extern char* ForceMainEqnWords[];
extern char* GageDataWords[];
extern char* InertDampingWords[];
extern char* InfilModelWords[];
extern char* LinkOffsetWords[];
extern char* LinkTypeWords[];
extern char* LoadUnitsWords[];
extern char* NodeTypeWords[];
extern char* NoneAllWords[];
extern char* NormalFlowWords[];
extern char* NormalizerWords[];
extern char* NoYesWords[];
extern char* OldRouteModelWords[];
extern char* OffOnWords[];
extern char* OptionWords[];
extern char* OrificeTypeWords[];
extern char* OutfallTypeWords[];
extern char* PatternTypeWords[];
extern char* PondingUnitsWords[];
extern char* ProcessVarWords[];
extern char* PumpTypeWords[];
extern char* QualUnitsWords[];
extern char* RainTypeWords[];
extern char* RainUnitsWords[];
extern char* ReportWords[];
extern char* RelationWords[];
extern char* RouteModelWords[];
extern char* RuleKeyWords[];
extern char* SectWords[];
extern char* SnowmeltWords[];
extern char* SurchargeWords[];                                                 //(5.1.013)
extern char* TempKeyWords[];
extern char* TransectKeyWords[];
extern char* TreatTypeWords[];
extern char* UHTypeWords[];
extern char* VolUnitsWords[];
extern char* VolUnitsWords2[];
extern char* WashoffTypeWords[];
extern char* WeirTypeWords[];
extern char* XsectTypeWords[];


#endif //KEYWORDS_H

==> SWMM5-5.2.0.post3.tar.gz: SWMM5-5.2.0.post3/swmm5/swmm5/keywords.h <==
//-----------------------------------------------------------------------------
//   keywords.h
//
//   Project: EPA SWMM5
//   Version: 5.2
//   Date:    11/01/21   (Build 5.2.0)
//   Author:  L. Rossman
//
//   Exportable keyword dictionary
//
//   Update History
//   ==============
//   Build 5.1.008:
//   - Keyword arrays listed in alphabetical order.
//   Build 5.1.013:
//   - New keyword array defined for surcharge method.
//-----------------------------------------------------------------------------

#ifndef KEYWORDS_H
#define KEYWORDS_H


extern char* BuildupTypeWords[];
extern char* CurveTypeWords[];
extern char* DividerTypeWords[];
extern char* DynWaveMethodWords[];
extern char* EvapTypeWords[];
extern char* FileModeWords[];
extern char* FileTypeWords[];
extern char* FlowUnitWords[];
extern char* ForceMainEqnWords[];
extern char* GageDataWords[];
extern char* InertDampingWords[];
extern char* InfilModelWords[];
extern char* LinkOffsetWords[];
extern char* LinkTypeWords[];
extern char* LoadUnitsWords[];
extern char* NodeTypeWords[];
extern char* NoneAllWords[];
extern char* NormalFlowWords[];
extern char* NormalizerWords[];
extern char* NoYesWords[];
extern char* OldRouteModelWords[];
extern char* OffOnWords[];
extern char* OptionWords[];
extern char* OrificeTypeWords[];
extern char* OutfallTypeWords[];
extern char* PatternTypeWords[];
extern char* PondingUnitsWords[];
extern char* ProcessVarWords[];
extern char* PumpTypeWords[];
extern char* QualUnitsWords[];
extern char* RainTypeWords[];
extern char* RainUnitsWords[];
extern char* ReportWords[];
extern char* RelationWords[];
extern char* RouteModelWords[];
extern char* RuleKeyWords[];
extern char* SectWords[];
extern char* SnowmeltWords[];
extern char* SurchargeWords[];
extern char* TempKeyWords[];
extern char* TransectKeyWords[];
extern char* TreatTypeWords[];
extern char* UHTypeWords[];
extern char* VolUnitsWords[];
extern char* VolUnitsWords2[];
extern char* WashoffTypeWords[];
extern char* WeirTypeWords[];
extern char* XsectTypeWords[];


#endif //KEYWORDS_H
